% this script demonstrates the Sound Quilting Toolbox
%
% uses default values from Nature Neuroscience (2015) quilting paper
%
% 7-16-2016 -- Josh McDermott (jhm@mit.edu)

which_source = input('Which source file to use (1=speech, 2=writing, 3=wind)? ');
segment_size_in_win = input('Segment size (number of 30 ms windows, e.g. 2)? ');

%values from NN paper:
win_ms = 30;
stim_length_in_sec=6;

P.filt_density = 1; %1 for regular filterbank, 2 for 4x overcomplete
P.N_audio_channel = 30;
P.audio_low_lim_Hz = 20;
P.audio_high_lim_Hz = 10000;
P.audio_sr = 20000;

if which_source==1
    [source_s,sr] = audioread('example_speech_source_file.wav');
elseif which_source==2
    [source_s,sr] = audioread('example_pencil_writing_source_file.wav');
elseif which_source==3
    [source_s,sr] = audioread('example_wind_source_file.wav');
end

if sr~=P.audio_sr
    source_s = resample(source_s,P.audio_sr,sr);
end

[quilted_s, final_seg_order, source_seg_changes, quilt_seg_changes, kl] = ...
    generate_quilt(source_s, win_ms, segment_size_in_win, stim_length_in_sec, P);

[n1,bins] = hist(source_seg_changes,40);
[n2,bins] = hist(quilt_seg_changes,bins);
figure; hold on
plot(bins,n1/sum(n1),'b','LineWidth',2);
plot(bins,n2/sum(n2),'r','LineWidth',2);
title('Between-Segment Changes in Original and Quilted Signals');
ylabel('Proportion');
xlabel('Size of change (arbitrary units)');
legend('Original Signal','Quilted Signal');
